@@ -20,13 +20,20 @@
 ## This is a common-ground for variables and defs that will be used from
 ## other modules - so they are global to everything.
 
-import sys, os, pickle, locale
+import sys, os, pickle
+
+import linux_safe_path_library
+LSP = linux_safe_path_library.linuxSafePath()
+
 import pathcontrol
 import strings
 import fontcontrol
 
+
+
+
 ## Ensure we have a .fontypython folder and a .fonts folder.
-iPC = pathcontrol.PathControl() #Make an instance - hence the small 'i'
+iPC = pathcontrol.PathControl() #Make an instance - hence the small 'i' (Boy this convention *sure* lasted....)
 
 ##  Borrowed from wxglade.py
 ## The reason for this is to find the path of this file
@@ -40,6 +47,78 @@ fontyroot = os.path.dirname(os.path.abspath(root))
 ## Where my images and things are.
 mythingsdir = os.path.join(fontyroot,"things/")
 
+
+## Sept 2009
+class Overlaperize(object):
+	'''
+	If a single font is in many pogs, then we count each 'overlap' and
+	control the removal of them until there are no overlaps anymore.
+	i.e. When no other installed pogs are using the font, it is safe to
+	remove the link (should that last pog be removed by the user).
+	'''
+	def __init__(self):
+		self.OVERLAP_COUNT_DICT = {}
+		self.DISABLE_THIS = False # In case all this makes a horrible mess : users can flip this to True....
+
+	def inc(self,key):
+		if self.DISABLE_THIS: return True
+
+		if key in self.OVERLAP_COUNT_DICT:
+			self.OVERLAP_COUNT_DICT[key] += 1
+		else:
+			self.OVERLAP_COUNT_DICT[key] = 2 #starts at 2 because there is already one installed.
+		#self.report(key)
+		return True
+
+	def dec(self,key):
+		'''
+		Return True means : This font overlaps
+		Return False means : This font can be uninstalled
+		'''
+		if self.DISABLE_THIS: return False
+
+		if key in self.OVERLAP_COUNT_DICT:
+			self.OVERLAP_COUNT_DICT[key] -= 1
+			if self.OVERLAP_COUNT_DICT[key] == 0:
+				del self.OVERLAP_COUNT_DICT[key]
+				return False # it does NOT overlap anymore.
+			else:
+				#self.report(key)
+				return True # It still overlaps
+
+		# It gets if the font is totally unknown to the OVERLAP_COUNT_DICT
+		return False #It therefore does NOT overlap.
+
+	def report(self,key):
+			print "%s has overlap count of %d" % (key, self.OVERLAP_COUNT_DICT[key])
+
+	def sleep(self):
+		'''Save the OVERLAP_COUNT_DICT to a file (if it has content). Called when app closes.'''
+		if self.DISABLE_THIS: return
+		
+		if not self.OVERLAP_COUNT_DICT:
+			self.OVERLAP_COUNT_DICT={} # Ensure there is a blank overlap_counts file!
+
+		paf = os.path.join(iPC.appPath(),"overlap_counts")
+		fr = open( paf, 'wb' ) # pickle says use 'binary' files, but only Windows makes this distinction. I use it to be safe...
+		pickle.dump( self.OVERLAP_COUNT_DICT, fr, protocol=pickle.HIGHEST_PROTOCOL )
+		fr.close()
+	
+	def wakeup(self):
+		'''Restore the OVERLAP_COUNT_DICT from a file (if any). Called as app starts.'''
+		if self.DISABLE_THIS: return 
+
+		paf = os.path.join(iPC.appPath(),"overlap_counts")
+		if os.path.exists( paf ):
+			fr = open( paf, "rb" )
+			self.OVERLAP_COUNT_DICT = pickle.load( fr )
+			fr.close()
+## start it up!
+Overlap = Overlaperize()
+Overlap.wakeup()
+
+
+
 ## Jan 18 2008
 segfonts = []# Global var
 
@@ -95,12 +174,11 @@ except:
 		if retval != 0:
 			segfault_I_hope = True
 		return segfault_I_hope
-   
 	printer ( _("Checking fonts, this could take some time.") )
 	printer ( _("Starting in %s:") % dirtocheck )
 	printer ()
 	## dirtocheck comes-in as unicode - let's stick to byte strings:
-	dirtocheck = dirtocheck.encode( locale.getpreferredencoding() )
+	dirtocheck = LSP.to_bytes( dirtocheck )
 	seglist = [] # our local list of newly found bad fonts
 	gotsome = False
 	for cwd, dirs, files in os.walk( dirtocheck ):
@@ -150,14 +228,9 @@ def isFolder(thing):
 def isPog(thing):
 	"""True if a Pog. False if not."""
 	## thing comes in as UNICODE
-##	## These come in handy when debugging Unicode errors
-##	print "thing:", thing
-##	print "type of thing:", type(thing)
-##	print
-##	print "iPC.getPogNames():", [iPC.getPogNames()]
 	## iPC.getPogNames() is a list of BYTE STRINGS
 	## We must encode thing to a byte string to avoid warnings:
-	if thing.encode(locale.getpreferredencoding()) in iPC.getPogNames(): #getPogNames contains UNICODE elements
+	if LSP.to_bytes( thing ) in iPC.getPogNames(): #getPogNames contains byte strings!
 		return True
 	if thing == "EMPTY": return True #Special case
 	return False
@@ -287,6 +360,8 @@ class Configure:
 		except IOError:
 			print _("Could not write to the config file.")
 
+		Overlap.sleep() #sept 2009 : Save the OVERLAP_COUNT_DICT
+
 
 ## Our config instance - it will have one instance across
 ## all the modules that use it.
@@ -412,15 +487,12 @@ def markInactive():
 	if state.viewobject and state.targetobject:
 		## What's in TARGET must be inactive in VIEW
 
-		## glyphpaf is a BYTE STRING... :(
 		## pafBlist is a list of UNICODEs
 		## glyphpaf_unicode is UNICODE, so I will use it instead		
 		## because we compare it to pafBlist
-#TO DO : I suspect there will be subtle problems here. Too tired now to test this.		
 		pafBlist = [i.glyphpaf_unicode for i in state.targetobject]
 
 		for iA in state.viewobject:
-			#print [iA.glyphpaf_unicode]
 			if iA.glyphpaf_unicode in pafBlist:
 				iA.activeInactiveMsg = _("This font is in %s") % state.targetobject.name
 				iA.inactive = True
@@ -445,63 +517,11 @@ def logSegfaulters( lastPaf ):
 	paf = os.path.join( iPC.appPath(),"lastFontBeforeSegfault")
 	try:
 		f = open( paf, "w" )
-		## Not tested yet....
-		if type( lastPaf ) is unicode:
-			lastPaf = lastPaf.encode( locale.getpreferredencoding() )
+		lastPaf = LSP.ensure_bytes( lastPaf )
 		f.write( lastPaf + "\n" )
 		f.close()
 	except:
 		raise
 
-def logBadStrings( badPaf ):
-	"""
-	Writes badfiles and appends strings to it.
-	
-	The usefulness of this routine is questioned. What does it acheive?
-	It's really storing names that can't be read under this locale,
-	but that does not mean the fonts are really bad in any way.
-	
-	Because the app may segfault at any time, I won't keep
-	this list in RAM - I open and kill duplicate lines and
-	sort and write it every time.
-	
-	This routine fair nearly killed me. Unicode issues! Damn.
-	"""
-	#print "BADPAF IS:", [badPaf]
-	## badPaf comes in BYTE STRING 99% of the time
-	## There are some corners where a UNICODE is sent-in
-	## I am writing an ASCII file. Oh great FSM, what am I gonna noodle now?
-	if type(badPaf) is unicode:
-		badPaf = badPaf.encode( locale.getpreferredencoding() )
-	
-	paf = os.path.join( iPC.appPath(),"badfiles")
-	
-	try:
-		if os.path.exists( paf ):
-			#read it
-			fr = open( paf, 'r' ) # byte string only ascii file
-			tmp = fr.read().split("\n")
-			fr.close()
-			tmp.append( badPaf )
-			uniquelines =  list( set( tmp ) )# remove dupes
-		else:
-			uniquelines = []
-			uniquelines.append( badPaf )
-		try:
-			uniquelines.sort( cmp = locale.strcoll )
-		except:
-			print "CORNER CASE ERROR in logBadStrings:"
-			print sys.exc_info()
-			raise SystemExit
-		
-		#Remove dupes, write.
-		fw = open( paf, "a" ) # byte string ascii
-		bytestring = "".join([line + "\n" for line in uniquelines if line != ""])
-		fw.write( bytestring )
-		fw.close()
 
-	except:
-		print "CORNER CASE ERROR in logBadStrings:"
-		print sys.exc_info()
-		raise SystemExit
 		
