@@ -37,8 +37,6 @@ import dialogues
 ## DND: NB--Comments that have DND: in them mean DO NOT DELETE. They are used by me via grep on the cli.
 
 
-#from gui_PogChooser import *
-
 from gui_Left import *
 from gui_Middle import *
 from gui_Right import *
@@ -88,7 +86,7 @@ class MainFrame(wx.Frame):
 		## Prepare the menu bar
 		self.menuBar = wx.MenuBar()
 
-		## FILE MENU
+		## FILE MENU : Changed to "Tools" menu Sep 2009
 		menu1 = wx.Menu()
 		menu1.Append(101, _("&Settings\tCtrl+S"), _("Change settings"))
 		menu1.AppendSeparator()
@@ -100,7 +98,7 @@ class MainFrame(wx.Frame):
 
 		self.exit = menu1.Append(104, _("&Exit"), _("Close the app"))
 		## Add menu to the menu bar
-		self.menuBar.Append(menu1, _("&File"))
+		self.menuBar.Append(menu1, _("&Tools"))
 
 
 		## SELECT MENU: June 2009
@@ -158,7 +156,7 @@ class MainFrame(wx.Frame):
 		(self.panelNotebook, -1, wx.Bitmap\
 		(fpsys.mythingsdir + 'icon_source_16x16.png', wx.BITMAP_TYPE_PNG))		
 		self.viewLabel = wx.StaticText\
-		(self.panelNotebook, -1, _("Source Folder, or Pog"), style = wx.ALIGN_LEFT)
+		(self.panelNotebook, -1, _("Source, Folder or Pog"), style = wx.ALIGN_LEFT)
 		self.viewLabel.SetFont\
 		(wx.Font(10, wx.FONTFAMILY_DEFAULT, wx.NORMAL, wx.FONTWEIGHT_BOLD))
 		
@@ -341,7 +339,6 @@ class MainFrame(wx.Frame):
 				fi.ticked=True
 				fpsys.state.numticks += 1
 		## Now update the view
-		#self.panelFontView.scrolledFontView.lastViewList=None #Force a redraw in the CreateFitmaps def.
 		ps.pub( update_font_view )	
 
 	def menuSelectionNONE(self,e):
@@ -351,7 +348,6 @@ class MainFrame(wx.Frame):
 			if not fi.inactive:
 				fi.ticked=False
 		## Now update the view
-		#self.panelFontView.scrolledFontView.lastViewList=None #Force a redraw in the CreateFitmaps def.
 		ps.pub( update_font_view )	
 
 	def TogglePurgeMenuItem(self, vis):
